@@ -1,15 +1,17 @@
 import logging
 import time
 import pkg_resources
-import json
 import os
 
-from typing import Dict, Any
+from typing import Dict, Any, TypeVar, Type, List
 
 import click
+import json
 
+from pydantic import parse_obj_as, ValidationError
 from gordo import __version__
 from gordo.workflow.config_elements.normalized_config import NormalizedConfig
+from gordo.workflow.config_elements.schemas import CustomEnv
 from gordo.workflow.workflow_generator import workflow_generator as wg
 from gordo.cli.exceptions_reporter import ReportLevel
 from gordo.util.version import parse_version
@@ -42,6 +44,45 @@ def get_builder_exceptions_report_level(config: NormalizedConfig) -> ReportLevel
     return report_level
 
 
+T = TypeVar("T")
+
+
+def parse_json(value: str, schema: Type[T]):
+    try:
+        data = json.loads(value)
+    except json.JSONDecodeError as e:
+        raise click.ClickException('Malformed JSON string: "%s"' % str(e))
+    try:
+        obj = parse_obj_as(schema, data)
+    except ValidationError as e:
+        raise click.ClickException('Schema validation error: "%s"' % str(e))
+    return obj
+
+
+DEFAULT_CUSTOM_MODEL_BUILDER_ENVS = """
+[
+    {
+        "name": "DL_SERVICE_AUTH_STR",
+        "valueFrom": {
+            "secretKeyRef": {
+                "key": "tenant_id_secret",
+                "name": "dlserviceauth"
+            }
+        }
+    },
+    {
+        "name": "DL2_SERVICE_AUTH_STR",
+        "valueFrom": {
+            "secretKeyRef": {
+                "key": "tenant_id_secret",
+                "name": "dl2serviceauth"
+            }
+        }
+    }
+]
+"""
+
+
 @click.group("workflow")
 @click.pass_context
 def workflow_cli(gordo_ctx):
@@ -183,6 +224,12 @@ def workflow_cli(gordo_ctx):
     help="Default imagePullPolicy for all gordo's images",
     envvar=f"{PREFIX}_IMAGE_PULL_POLICY",
 )
+@click.option(
+    "--custom-model-builder-envs",
+    help="List of custom environment variables in ",
+    envvar=f"{PREFIX}_CUSTOM_MODEL_BUILDER_ENVS",
+    default=DEFAULT_CUSTOM_MODEL_BUILDER_ENVS,
+)
 @click.pass_context
 def workflow_generator_cli(gordo_ctx, **ctx):
     """
@@ -203,6 +250,13 @@ def workflow_generator_cli(gordo_ctx, **ctx):
     # Create normalized config
     config = NormalizedConfig(yaml_content, project_name=context["project_name"])
 
+    if context["custom_model_builder_envs"]:
+        result = parse_json(context["custom_model_builder_envs"], List[CustomEnv])
+        custom_model_builder_envs = []
+        for value in result:
+            custom_model_builder_envs.append(value.dict(exclude_defaults=True))
+        context["custom_model_builder_envs"] = custom_model_builder_envs
+
     version = parse_version(context["gordo_version"])
     if "image_pull_policy" not in context or not context["image_pull_policy"]:
         context["image_pull_policy"] = wg.default_image_pull_policy(version)
@@ -229,11 +283,21 @@ def workflow_generator_cli(gordo_ctx, **ctx):
     ]
     context["model_builder_resources_limits_cpu"] = builder_resources["limits"]["cpu"]
 
+    context["model_builder_image"] = config.globals["runtime"]["builder"]["image"]
+
     context["server_resources"] = config.globals["runtime"]["server"]["resources"]
+    context["server_image"] = config.globals["runtime"]["server"]["image"]
+
     context["prometheus_metrics_server_resources"] = config.globals["runtime"][
         "prometheus_metrics_server"
     ]["resources"]
 
+    context["prometheus_metrics_server_image"] = config.globals["runtime"][
+        "prometheus_metrics_server"
+    ]["image"]
+
+    context["deployer_image"] = config.globals["runtime"]["deployer"]["image"]
+
     # These are also set in the default globals, and guaranteed to exist
     client_resources = config.globals["runtime"]["client"]["resources"]
     context["client_resources_requests_memory"] = client_resources["requests"]["memory"]
@@ -241,6 +305,8 @@ def workflow_generator_cli(gordo_ctx, **ctx):
     context["client_resources_limits_memory"] = client_resources["limits"]["memory"]
     context["client_resources_limits_cpu"] = client_resources["limits"]["cpu"]
 
+    context["client_image"] = config.globals["runtime"]["client"]["image"]
+
     context["client_max_instances"] = config.globals["runtime"]["client"][
         "max_instances"
     ]
