@@ -15,7 +15,7 @@ from gordo import __version__, serializer
 from gordo.server.rest_api import Api
 from gordo.server import utils as server_utils
 from gordo.machine.model import utils as model_utils
-from gordo.machine.dataset.sensor_tag import SensorTag, normalize_sensor_tags
+from gordo_dataset.sensor_tag import SensorTag, normalize_sensor_tags
 from gordo.server import model_io
 
 
